# Hyperspectral Image Analysis for Moss Samples

This is an in-progress pipeline for processing hyperspectral images of moss samples.

```
python -m build
python -m twine upload --repository hsi_moss dist/*
```